<?php
/**
 *
 * ArrayQueryTest
 *
 * @author Antonio Ramirez <amigo.cobos@gmail.com>
 * @link http://www.ramirezcobos.com/
 * @link http://www.2amigos.us/
 */
namespace dosamigos\arrayquery\tests;

class ArrayQueryTest extends \PHPUnit_Framework_TestCase
{
	protected $array;
	protected $query;

	protected function setUp()
	{
		$this->array = [
			[
				'name' => 'Antonio',
				'surname' => 'Ramirez',
				'age' => 42,
				'parents' => [
					'father' => [
						'name' => 'Antonio',
						'surname' => 'FirstA SecondA'
					],
					'mother' => [
						'name' => 'Antonia',
						'surname' => 'FirstB SecondB'
					]
				]
			],
			[
				'name' => 'John',
				'surname' => 'Doe',
				'age' => 18,
				'parents' => [
					'father' => [
						'name' => 'John',
						'surname' => 'FirstA SecondA'
					],
					'mother' => [
						'name' => 'Janet',
						'surname' => 'FirstB SecondB'
					]
				]
			],
		];

		$this->query = new \dosamigos\arrayquery\ArrayQuery($this->array);
	}

	public function testTokenizer()
	{
		$paths = $this->query->tokenize($this->array);

		$this->assertArrayHasKey('parents.father.name', $paths);
	}

	public function testEqual()
	{
		$result = $this->query->addCondition('name', 'John')->find();
		$this->assertCount(1, $result);
		$this->assertEquals("John", $result[1]['name']);
	}

	public function testGreaterThan()
	{
		$result = $this->query->addCondition('age', '>30')->one();
		$this->assertEquals("Antonio", $result['name']);
	}

	public function testGreaterThanOrEqual()
	{
		$result = $this->query->addCondition('age', '>=42')->one();
		$this->assertEquals("Antonio", $result['name']);
	}

	public function testLessThan()
	{
		$result = $this->query->addCondition('age', '<30')->one();
		$this->assertEquals("John", $result['name']);
	}

	public function testLessThanOrEqual()
	{
		$result = $this->query->addCondition('age', '<=30')->one();
		$this->assertEquals("John", $result['name']);
	}

	public function testLike()
	{
		$result = $this->query->addCondition('name', '~toni')->one();
		$this->assertEquals("Antonio", $result['name']);
		$result = $this->query->addCondition('name', 'like toni')->one();
		$this->assertEquals("Antonio", $result['name']);
	}

	public function testNotLike()
	{
		$result = $this->query->addCondition('name', 'n~toni')->one();
		$this->assertEquals("John", $result['name']);
		$result = $this->query->addCondition('name', 'nlike toni')->one();
		$this->assertEquals("John", $result['name']);
	}

	public function testOne()
	{
		$result = $this->query->addCondition('name', 'Antonio')->one();
		$this->assertEquals('Ramirez', $result['surname']);
	}
} 